******************************************************************************
*    Responsiveness of Discount Rate to Experimental Methods of Estimate     *
******************************************************************************
* Stata 14
* ************* Feb 22th, 2019
*********  *********
*ssc install estout
*ssc install ivreg2
*ssc install winsor
*findit collin
*********  *********
*log close
clear
log using discrate.log, replace
cd "/Users/jm/Google Drive/IES_PhD/Research/2-Meta-Analyses/2018_Discrate/Methods"
import excel using discrate_data.xls, sheet("stata") firstrow
*data to panel
xtset idstudy
*not to pause execution
set more off

********************************************************************************
* Data operations discrate_data.dta
********************************************************************************
destring discrate_se, replace ignore("na")
destring tstat, replace ignore("na")
save discrate_data.dta, replace
********************************************************************************
* Resampling stderrors - BOOTSTRAPPING
********************************************************************************
use discrate_data.dta, replace
generate discrate_boot = discrate
save discrate_data_boot.dta, replace
 
summarize idstudy
local boots = r(max)
*local boots = 2
local reps = 1000

***generating blank dataset for storage
clear
set obs `boots'
generate idstudy = .
generate store_means = .
generate original_means = .
generate store_stdevs = .

*making output quietly
quietly{
	*bootstrapping for each study in the panel
	forvalues i = 1(1) `boots' {
		*preserving generated storage dataset
		preserve
		
		use discrate_boot idstudy using discrate_data_boot.dta, clear
		
		*adding counter and display noisily
		if floor((`i'-1)/1) == (`i'-1)/1 {
			noisily display "Worknig on `i' out of `boots' at $S_TIME"
		}
		*keep the data for i-th study only
		keep if idstudy==`i'
		
		*storing mean coefficient of original data
		summarize discrate_boot
		local mean_discrate_orig = r(mean)
	
		*tempfile boot_study_`i'

		*actual bootstrapping
		*bsample
		bootstrap mean=r(mean), reps(`reps') strata(idstudy) seed(1234) saving(boot_study_`i', replace): summarize discrate_boot, detail
		*estat bootstrap, all
		*so the problem is that the bootstrapped command does not pass the stored result from r(mean)-probably it even does not do so...		
		use boot_study_`i', replace
		summarize mean
		*storing into local macro
		local mean_discrate = r(mean)
		local mean_discrate_sd = r(sd)		
		
		*restoring generated storage dataset
		restore
		
		replace idstudy = `i' in `i'
		
		display "replacing store_means = `mean_discrate' in `i'"	
		replace store_means = `mean_discrate' in `i'
		display "replacing original_means = `mean_discrate_orig' in `i'"
		replace original_means = `mean_discrate_orig' in `i'
		display "replacing store_stdevs = `mean_discrate_sd' in `i'"
		replace store_stdevs = `mean_discrate_sd' in `i'
	}
}
*saving bootstrapped results
save boot_results.dta, replace

*merge and store
use discrate_data_boot.dta, replace
merge m:1 idstudy using boot_results.dta

drop _merge store_means discrate_boot
rename original_means study_mean
rename store_stdevs study_se

save discrate_data_boot.dta, replace
********************************************************************************
* Data operations discrate_data_boot.dta
****************************ą***************************************************
use discrate_data_boot.dta, replace

*winsorization levels
local p = 0.05
*winsorizing basic vars
winsor discrate, gen(discrate_win) p(`p')
winsor discrate_se, gen(discrate_se_win) p(`p')
winsor tstat, gen(tstat_win) p(`p')
winsor discrate_prec, gen(discrate_prec_win) p(`p')

*combining bootstrapped and reported stderrors
generate discrate_se_comb = .
replace discrate_se_comb = discrate_se if discrate_se != .
replace discrate_se_comb = study_se if discrate_se == .
winsor discrate_se_comb, gen(discrate_se_comb_win) p(`p')

*generate quadratic SE
generate discrate_se2 = .
replace discrate_se2 = discrate_se^2
winsor discrate_se2, gen(discrate_se2_win) p(`p')

*generate quadratic SE combined
generate discrate_se_comb2 = .
replace discrate_se_comb2 = discrate_se_comb^2
winsor discrate_se_comb2, gen(discrate_se_comb2_win) p(`p')

*generate precision for combined se
generate discrate_se_comb_prec = .
replace discrate_se_comb_prec = (1 / discrate_se_comb)

*not to loose 2 obs
generate discrate_se_comb_prec_win = .
replace discrate_se_comb_prec_win = (1 / discrate_se_comb_win)

*generate combined tstats
generate tstat_comb = .
replace tstat_comb = (discrate / discrate_se_comb)

*not to loose 2 obs
generate tstat_comb_win = .
replace tstat_comb_win = (discrate_win / discrate_se_comb_win)

*generate dummy for dep_var - frequentist check
generate disc_factor = 0
replace disc_factor = 1 if dep_var == "Discount Factor"

*generate log of discrate precision - for funnel plot
generate discrate_se_comb_prec_log = .
replace discrate_se_comb_prec_log = ln(discrate_se_comb_prec)

*Labelling variables
label variable discrate "Discount rate"
label variable discrate_se_comb_win "SE (publication bias)"
label variable discrate_se_comb2_win "\$SE^{2}$ (publication bias)"

*saving bootstrapped data
save discrate_data_boot_win.dta, replace
********************************************************************************
* Summary statistics and graphs
********************************************************************************
use discrate_data_boot_win.dta, replace

summarize discrate discrate_se discrate_se_comb
summarize discrate if discrate_se != .

********* Histograms *********
summarize discrate, detail
local m = r(mean)
local med = r(p50)
*local ubound = r(p99)
local ubound = 1
graph twoway histogram discrate if discrate < `ubound', ///
	bin(20) start(-0.25) /*color(ltblue%30)*/ frequency ///
	xline(`m', lpattern(solid) lcolor(red)) ///
    xline(`med', lpattern(dash) lcolor(red)) ///
	saving(_hist_discrate, replace)
graph use _hist_discrate
graph export _hist_discrate.pdf, replace

********* Horizontal boxplots *********
summarize discrate, detail
local m = r(mean)
local med = r(p50)
local ubound = r(p99)
graph hbox discrate if discrate < `ubound', ///
	over(author) xsize(7) ysize(8) scale(0.6) yline(`m', lpattern(solid)) ///
	saving(_authors, replace)
graph hbox discrate if discrate < `ubound', ///
	over(country) xsize(2.5) ysize(1) scale(1.5) yline(`m', lpattern(solid)) ///
	saving(_countries, replace)

***saving boxplots
graph use _authors
graph export _authors.pdf, replace
graph use _countries
graph export _countries.pdf, replace
********************************************************************************
* Patterns
********************************************************************************
********* pattern over pubyear *********
summarize discrate, detail
local ubound = r(p99)
graph twoway (scatter discrate pubyear if discrate < `ubound', ///
	msize(*1) msymbol(Oh)) (lfit discrate pubyear, lcolor(black)), ///
	xtitle("Publication year") ytitle("Discount rate") legend(off) ///
	saving(_trend, replace)

********* pattern over time horizon of the task *********
summarize timelength, detail
local ubound_t = r(p95)
graph twoway (scatter discrate timelength if (discrate < `ubound' & timelength < `ubound_t'), ///
	msize(*1) msymbol(Oh)) ///
	(lfit discrate_win timelength if timelength < `ubound_t', lcolor(black)), ///
	xtitle("Time horizon of the task") ///
	ytitle("Discount rate") ///
	legend(off) ///
	saving(_horizon, replace)

*saving patterns
graph use _trend
graph export _trend.pdf, replace
graph use _horizon
graph export _horizon.pdf, replace
********************************************************************************
* Funnel plot, check for publication bias
********************************************************************************
summarize discrate, detail
local m = r(mean)
local ubound = r(p99)
twoway scatter discrate_se_comb_prec_log discrate if discrate < `ubound', ///
	ytitle("Log of discount rate precision (log(1/SE))") ///
	xtitle("Discount rate") ///
	xline(`m', lpattern(solid) lcolor (black)) ///
	xline(0, lpattern(dash) lcolor (black)) ///
	saving(_funnel_discrate, replace)

* Funnel with bounds
local ubound_x = 3
local ubound_y = 8
twoway scatter discrate_se_comb_prec_log discrate ///
	if discrate_se_comb_prec_log < `ubound_y' & discrate < `ubound_x', ///
	ytitle("Log of discount rate precision (log(1/SE))") ///
	xtitle("Discount rate") /*xline(`m', lpattern(solid) lcolor (black))*/ ///
	xline(0, lpattern(dash) lcolor (black)) ///
	saving(_funnel_discrate_bound, replace) //

*saving Funnels
graph use _funnel_discrate
graph export _funnel_discrate.pdf, replace
graph use _funnel_discrate_bound
graph export _funnel_discrate_bound.pdf, replace
*******************************************************************************
* Funnel Assymetry Tests
********************************************************************************

**** PET ****
*regression p-weighted by winsorized combined 1/SE, clustered on study level
eststo: ivreg2 discrate_win discrate_se_comb_win [pweight = discrate_se_comb_prec_win], cluster(idstudy)

*FE regresssion, clustered on study level only
eststo: xtreg tstat_comb_win discrate_se_comb_prec_win, fe cluster(idstudy)

*FE+IV regression, clustered on study level
eststo: xi, noomit: ivreg2 tstat_comb_win i.idstudy (discrate_se_comb_prec_win=instrument), cluster(idstudy)

*OLS regresssion, non-weighted, clustered on study level only
eststo: ivreg2 discrate_win discrate_se_comb_win, cluster(idstudy)

*PET test - p-weighted by inverse of number per study estimates 
eststo: ivreg2 discrate_win discrate_se_comb_win [pweight = invperst], cluster(idstudy)

*saving PET tests
esttab using _pet.tex, se booktabs replace compress title(Funnel asymmetry tests - PET /// \
	\label{tab: PET results}) mtitles("Precision" "FE" "FE+IV" "OLS" "Study") /// \
	///addnote("Standard errors are clustered at the study level.") /// \
	star(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) /// \
	label nonumber nogaps width(1\\hsize)
eststo clear

**** PEESE ****
*regression p-weighted by winsorized combined 1/SE, clustered on study level 
eststo: ivreg2 discrate_win discrate_se_comb2_win [pweight = discrate_se_comb_prec_win], cluster(idstudy)

*FE with constrained coefficients
	***imposing constraints
	forvalues i = 1(1)34 {
		constraint `i' _Iidstudy_`i' = 0 
		}
	***constraint regression estimate
	eststo: xi, noomit: cnsreg tstat_comb_win discrate_se_comb_win discrate_se_comb_prec_win i.idstudy, cluster(idstudy) noconst constraint(1-34)
	*test of v_i = 0
		lincom _Iidstudy_1 + _Iidstudy_2 + _Iidstudy_3 + _Iidstudy_4 + _Iidstudy_5 + _Iidstudy_6 + _Iidstudy_7 /// \
		+ _Iidstudy_8 + _Iidstudy_9 + _Iidstudy_10 + _Iidstudy_11 + _Iidstudy_12 + _Iidstudy_13 + _Iidstudy_14 + /// \
		_Iidstudy_15 + _Iidstudy_16 + _Iidstudy_17 + _Iidstudy_18 + _Iidstudy_19 + _Iidstudy_20 + _Iidstudy_21 + /// \
		_Iidstudy_22 + _Iidstudy_23 + _Iidstudy_24 + _Iidstudy_25 + _Iidstudy_26 + _Iidstudy_27 + _Iidstudy_28 + /// \
		_Iidstudy_29 + _Iidstudy_30 + _Iidstudy_31 + _Iidstudy_32 + _Iidstudy_33 + _Iidstudy_34

*** FE+IV
eststo: xi, noomit: ivreg2 tstat_comb_win discrate_se_comb_win i.idstudy (discrate_se_comb_prec_win=instrument), cluster(idstudy) noconst
*test of v_i = 0
lincom _Iidstudy_1 + _Iidstudy_2 + _Iidstudy_3 + _Iidstudy_4 + _Iidstudy_5 + _Iidstudy_6 + _Iidstudy_7 /// \
	+ _Iidstudy_8 + _Iidstudy_9 + _Iidstudy_10 + _Iidstudy_11 + _Iidstudy_12 + _Iidstudy_13 + _Iidstudy_14 + /// \
	_Iidstudy_15 + _Iidstudy_16 + _Iidstudy_17 + _Iidstudy_18 + _Iidstudy_19 + _Iidstudy_20 + _Iidstudy_21 + /// \
	_Iidstudy_22 + _Iidstudy_23 + _Iidstudy_24 + _Iidstudy_25 + _Iidstudy_26 + _Iidstudy_27 + _Iidstudy_28 + /// \
	_Iidstudy_29 + _Iidstudy_30 + _Iidstudy_31 + _Iidstudy_32 + _Iidstudy_33 + _Iidstudy_34

*OLS regresssion, non-weighted, clustered on study level only
eststo: ivreg2 discrate_win discrate_se_comb2_win, cluster(idstudy)

*PET test - p-weighted by inverse of number per study estimates 
eststo: ivreg2 discrate_win discrate_se_comb2_win [pweight = invperst], cluster(idstudy)

*saving PEESE tests
esttab using _peese.tex, se booktabs replace compress title(Funnel asymmetry tests - PEESE /// \
	\label{tab: PEESE results}) mtitles("Precision" "FE" "FE+IV" "OLS" "Study") /// \
	///addnote("Standard errors are clustered at the study level.") /// \
	star(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) /// \
	label nonumber nogaps width(1\\hsize)
eststo clear

***** TOP10 method *****
summarize discrate_se_comb_prec, detail
local top10bound = r(p90)
summarize discrate discrate_se_comb_prec if discrate_se_comb_prec > `top10bound'

***** Stem-based method in R, Chishio Furukawa
***** https://github.com/Chishio318/stem-based_method
***** See R part of this code

******************************************************************************
* ROBUSTNESS CHCEKS
******************************************************************************
**** REPORTED SE ONLY ****

**** PET ****
*regression p-weighted by winsorized combined 1/SE, clustered on study level
eststo: ivreg2 discrate_win discrate_se_win if !missing(discrate_se) [pweight = discrate_prec_win], cluster(idstudy)

*FE regresssion, clustered on study level only
eststo: xtreg tstat_win discrate_prec_win if !missing(discrate_se), fe cluster(idstudy)

*FE+IV regression, clustered on study level
eststo: xi, noomit: ivreg2 tstat_win i.idstudy (discrate_prec_win=instrument) if !missing(discrate_se), cluster(idstudy)

*OLS regresssion, non-weighted, clustered on study level only
eststo: ivreg2 discrate_win discrate_se_win if !missing(discrate_se), cluster(idstudy)

*PET test - p-weighted by inverse of number per study estimates 
eststo: ivreg2 discrate_win discrate_se_win if !missing(discrate_se) [pweight = invperst], cluster(idstudy)

*saving PET tests
esttab using _pet_rcheck.tex, se booktabs replace compress title(Funnel asymmetry tests - PET /// \
	\label{tab: PET results - RC}) mtitles("Precision" "FE" "FE+IV" "OLS" "Study") /// \
	///addnote("Standard errors are clustered at the study level.") /// \
	star(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) /// \
	label nonumber nogaps width(1\\hsize)
eststo clear

**** PEESE ****
*regression p-weighted by winsorized combined 1/SE, clustered on study level 
eststo: ivreg2 discrate_win discrate_se2_win if !missing(discrate_se) [pweight = discrate_prec_win], cluster(idstudy)

*FE with constrained coefficients
	***imposing constraints
	forvalues i = 1(1)34 {
		constraint `i' _Iidstudy_`i' = 0 
		}
	***constraint regression estimate
	eststo: xi, noomit: cnsreg tstat_win discrate_se_win discrate_prec_win i.idstudy if !missing(discrate_se), cluster(idstudy) noconst constraint(1-34)
	*test of v_i = 0
	lincom _Iidstudy_1 + _Iidstudy_2 + _Iidstudy_3 + _Iidstudy_4 + _Iidstudy_5 + _Iidstudy_6 + _Iidstudy_7 /// \
		+ _Iidstudy_8 + _Iidstudy_9 + _Iidstudy_10 + _Iidstudy_11 + _Iidstudy_12 + _Iidstudy_13 + _Iidstudy_14 + /// \
		_Iidstudy_15 + _Iidstudy_16 + _Iidstudy_17 + _Iidstudy_18 + _Iidstudy_19 + _Iidstudy_20 + _Iidstudy_21 + /// \
		_Iidstudy_22 + _Iidstudy_23 + _Iidstudy_24 + _Iidstudy_25 + _Iidstudy_26 + _Iidstudy_27 + _Iidstudy_28 + /// \
		_Iidstudy_29 + _Iidstudy_30 + _Iidstudy_31 + _Iidstudy_32 + _Iidstudy_33 + _Iidstudy_34

*** FE+IV
eststo: xi, noomit: ivreg2 tstat_win discrate_se_win i.idstudy (discrate_prec_win=instrument) if !missing(discrate_se), cluster(idstudy) noconst
*test of v_i = 0
lincom _Iidstudy_1 + _Iidstudy_2 + _Iidstudy_3 + _Iidstudy_4 + _Iidstudy_5 + _Iidstudy_6 + _Iidstudy_7 /// \
	+ _Iidstudy_8 + _Iidstudy_9 + _Iidstudy_10 + _Iidstudy_11 + _Iidstudy_12 + _Iidstudy_13 + _Iidstudy_14 + /// \
	_Iidstudy_15 + _Iidstudy_16 + _Iidstudy_17 + _Iidstudy_18 + _Iidstudy_19 + _Iidstudy_20 + _Iidstudy_21 + /// \
	_Iidstudy_22 + _Iidstudy_23 + _Iidstudy_24 + _Iidstudy_25 + _Iidstudy_26 + _Iidstudy_27 + _Iidstudy_28 + /// \
	_Iidstudy_29 + _Iidstudy_30 + _Iidstudy_31 + _Iidstudy_32 + _Iidstudy_33 + _Iidstudy_34

*OLS regresssion, non-weighted, clustered on study level only
eststo: ivreg2 discrate_win discrate_se2_win if !missing(discrate_se), cluster(idstudy)

*PET test - p-weighted by inverse of number per study estimates 
eststo: ivreg2 discrate_win discrate_se2_win if !missing(discrate_se) [pweight = invperst], cluster(idstudy)

*saving PEESE tests
esttab using _peese_rcheck.tex, se booktabs replace compress title(Funnel asymmetry tests - PEESE /// \
	\label{tab: PEESE results - RC}) mtitles("Precision" "FE" "FE+IV" "OLS" "Study") /// \
	///addnote("Standard errors are clustered at the study level.") /// \
	star(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) /// \
	label nonumber nogaps width(1\\hsize)
eststo clear
******************************************************************************
* FREQUENTIST CHECK OF BMA
******************************************************************************

summarize discrate_se_comb_win exponential ln_timelength method_exp domain_other students continent_africa
correlate discrate_se_comb_win exponential ln_timelength method_exp domain_other students continent_africa
collin discrate_se_comb_win exponential ln_timelength method_exp domain_other students continent_africa

*** UIP prior ***
eststo: reg discrate_win ///
	discrate_se_comb_win exponential ln_timelength method_exp domain_other students continent_africa ///
	, cluster(idstudy)

*saving freq check
esttab using _freqcheck.tex, se booktabs replace compress title(Frequentist check /// \
	\label{tab: frequentist check}) /// mtitles("xxx") /// \
	star(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) /// \
	label nonumber nogaps width(1\\hsize)
eststo clear
******************************************************************************
window manage close graph
log close
exit, clear

/*

#******************************************************************************
#******************************************************************************
#* R-PART OF THE CODE
#******************************************************************************
#******************************************************************************

sink("./discrate_bms_log.txt", append = FALSE)
#install.packages("BMS")
#install.packages("xlsx")
#install.packages("RStata")
#install.packages("stargazer")
#install.packages("readstata13")
#install.packages("dplyr")
#install.packages("robustHD")
setwd("~/Google Drive/IES_PhD/Research/2-Meta-Analyses/2018_Discrate/Methods")

#***** USER DEFINED FUNCTIONS *************************************************
{
  # Get upper triangle of the correlation matrix
  get_upper_tri <- function(mat){
    mat[lower.tri(mat)]<- NA
    return(mat)
  }

  # Get lower triangle of the correlation matrix
  get_lower_tri <- function(mat){
    mat[upper.tri(mat)]<- NA
    return(mat)
  }

  # Visualization of matrices
  visualiseMatrix <- function(matrix, type){
    library(ggplot2)
    
    # melting the matrix
    library(reshape2)
    melted_matrix <- melt(matrix, na.rm = TRUE)
    
    # generating heatmap
    ggheatmap <- {ggplot(melted_matrix, aes(Var2, Var1, fill = value))+
        geom_tile(color = "white")+
        scale_fill_gradient2(low = "blue", high = "red", mid = "white", midpoint = 0, limit = c(-1,1), space = "Lab", name="Pearson\nCorrelation")+
        theme_minimal()+ # minimal theme
        theme(axis.text.x = element_text(angle = 45, vjust = 1, size = 12, hjust = 1))+
        coord_fixed() +
        geom_text(aes(Var2, Var1, label = value), color = "black", size = 1.5) #+
      # theme(
      #   axis.title.x = element_blank(),
      #   axis.title.y = element_blank(),
      #   panel.grid.major = element_blank(),
      #   panel.border = element_blank(),
      #   panel.background = element_blank(),
      #   axis.ticks = element_blank(),
      #   legend.justification = c(1, 0),
      #   legend.position = c(0.6, 0.7),
      #   legend.direction = "horizontal")+
      #guides(fill = guide_colorbar(barwidth = 7, barheight = 1,
      #                             title.position = "top", title.hjust = 0.5))
    }

    # Print the heatmap to the file
    pdf(paste("", type, "matrix.pdf", sep="_"))
    print(ggheatmap)
    dev.off()
  }

  # Print the output to the LaTex file
  printLatex <- function(what, where, itsTitle){
    sink(paste("./_", where, ".tex", sep = ""), append = FALSE)
    library(stargazer)
    stargazer(what, title = itsTitle, align = FALSE)
    sink()
  }

  # Add labels to datadiscrate
  var.labels <-  c(discrate = "Discount.rate",
                   discrate_win = "Discount.rate",
                   discrate_se = "SE",
                   discrate_se_win = "SE",
                   discrate_se_comb = "SE",
                   discrate_se_comb_win = "SE",
                   disc_factor = "Discount.factor",
                   hyperbolic = "Hyperbolic.disc",
                   exponential = "Exponential.disc",
                   ln_timelength = "Delay",
                   idtimehorizon = "Max.delay",
                   method_exp = "Lab.experiment",
                   ln_samplesize = "Sample.size",
                   reward_real = "Real.reward",
                   elicmethod_match = "Matching.task",
                   domain_health = "Health.domain",
                   domain_other = "Other.domain",
                   framing_negative = "Negative.framing",
                   framing_neutral = "Neutral.framing",
                   students = "Students",
                   male = "Males.only",
                   female = "Females.only",
                   continent_namerica = "North.America",
                   continent_asia = "Asia",
                   continent_africa = "Africa",
                   ln_google_per_year = "Citations",
                   std_pubyear = "Publication.year"
  )
}
#***** DATA OPERATIONS ********************************************************
#input Stata file
  library(readstata13)
  databoot <- read.dta13("discrate_data_boot_win.dta") # Winsorized data

#reading the bma.csv file
  datadiscrate <- read.csv("bma.csv", header = TRUE, sep = ",", dec = ".", stringsAsFactors = TRUE)

#replacing and renaming combined SE
  datadiscrate$discrate_se <- databoot$discrate_se_comb
  names(datadiscrate)[names(datadiscrate)=="discrate_se"] <- "discrate_se_comb"

#Winsorization of datadiscrate
  datadiscrate_win <- datadiscrate

  #replacing and renaming for win data
    datadiscrate_win$discrate <- databoot$discrate_win
    names(datadiscrate_win)[names(datadiscrate_win)=="discrate"] <- "discrate_win"
    datadiscrate_win$discrate_se_comb <- databoot$discrate_se_comb_win
    names(datadiscrate_win)[names(datadiscrate_win)=="discrate_se_comb"] <- "discrate_se_comb_win"

  #renaming data for visualization
  names(datadiscrate) <- as.list(var.labels[match(names(datadiscrate), names(var.labels))])
  names(datadiscrate_win) <- as.list(var.labels[match(names(datadiscrate_win), names(var.labels))])

#***** VARIABLE SUMMARIES AND TABLES ******************************************
#summary of whole datadiscrate
  printLatex(datadiscrate, "summ_datadiscrate", "Summary of the Dataset")

#summary of the basic variables
  keep <- c("discrate", "discrate_se", "discrate_se_comb")
  printLatex(subset(databoot, select = keep), "summ_selectedVars", "Summary statistics of selected variables")

#******************************************************************************
#* Correlations, Covariances, VIF
#******************************************************************************
{
  #Correlations
  corrs <- round(cor(datadiscrate, use="complete.obs", method="kendall"), 3)
  corrsLower <- get_lower_tri(corrs)

  #Visualisation of matrix
    visualiseMatrix(corrsLower, "correlations_lower")

  #Covariances
  covs <- round(cov(datadiscrate, use="complete.obs"), 2)
  covsLower <- get_lower_tri(covs)

  #Visualisation of matrix
    visualiseMatrix(covsLower, "covariances_lower")

  #Variance inflation factor - VIF (if VIF > 10 -> collin problem)
  library(car)
  form.in<-paste('Discount.rate ~ ',paste(names(datadiscrate)[-1],collapse='+')) # creating a string of all variables
  model<-lm(form.in,data=datadiscrate) # fitting the model on the discrate data
  vif <- vif(model)
  printLatex(vif, "vif", "Variance Inflation Factor")
}

#******************************************************************************
#* STEM-BASED METHOD OF SELECTIVE REPORTING
#******************************************************************************
  source("stem_method.R", local = TRUE)
  ## https://github.com/Chishio318/stem-based_method
  stem_results <- stem(datadiscrate_win$Discount.rate, datadiscrate_win$SE, param)
  printLatex(stem_results$estimates, "stem", "Results of Stem-based selective reporting")

#******************************************************************************
#* HETEROGENEITY - BAYESIAN MODEL AVERAGING
#******************************************************************************

# initialization of data for BMA
  bmaData <- datadiscrate_win

# BMA settings
  bmaIter <- 2e6
  bmaBurns <- 1e6
  bmaNmodel <- 5000

#***** UIP PRIOR **************************************************************
library(BMS)

#main BMA simulations
  discrate_uip = bms(bmaData, burn=bmaBurns, iter=bmaIter, g="UIP", mprior="uniform", nmodel=bmaNmodel, mcmc="bd", user.int=FALSE)

#saving postestimation
  pdf("_discrate_post_uip.pdf")
  plot(discrate_uip)
  dev.off()

#summary stats
  summary(discrate_uip)
  coef(discrate_uip, order.by.pip = F, exact=T, include.constant=T)

#saving cumulative bma plot
  pdf("_discrate_bma_uip.pdf")
  image(discrate_uip, cex.axis=0.8, order.by.pip = T, yprop2pip=F)
  dev.off()

#top 5 models
  top5Uip <- topmodels.bma(discrate_uip)[, 1:5]
  printLatex(top5Uip, "top5UIP", "Five top models of UIP prior BMA analysis")
  topUip <- discrate_uip$topmod[1] #included variables in the best model
  print(topUip)

# Best model
  uip_best <- as.zlm(discrate_uip, model = 1)
  summary(uip_best)

#***** BRIC PRIOR *************************************************************
library(BMS)

#main BMA simulations
  discrate_bric = bms(bmaData, burn=bmaBurns, iter=bmaIter, g="BRIC", mprior="random", nmodel=bmaNmodel, mcmc="bd", user.int=FALSE)

#saving postestimation
  pdf("_discrate_post_bric.pdf")
  plot(discrate_bric)
  dev.off()

#summary stats
  summary(discrate_bric)
  coef(discrate_bric, order.by.pip = F, exact=T, include.constant=T)

#saving cumulative bma plot
  pdf("_discrate_bma_bric.pdf")
  image(discrate_bric, cex.axis=0.8, order.by.pip = T, yprop2pip=F)
  dev.off()

#top 5 models
  top5Bric <- topmodels.bma(discrate_bric)[, 1:5]
  printLatex(top5Bric, "top5BRIC", "Five top models of BRIC prior BMA analysis")
  topBric <- discrate_bric$topmod[1] #included variables in the best model
  print(topBric)

# Best model
  bric_best <- as.zlm(discrate_bric, model = 1)
  summary(bric_best)

#***** ROBUSTNESS CHECK FOR discrate_SE- UIP PRIOR ONLY************************
library(dplyr)
library(BMS)

#read original data
  datadiscrate_rc <- read.csv("bma.csv", header = TRUE, sep = ",", dec = ".", stringsAsFactors = TRUE)

  #replacing discrate and discrate_se with winsorized variables
  datadiscrate_rc$discrate <- databoot$discrate_win
  names(datadiscrate_rc)[names(datadiscrate_rc)=="discrate"] <- "discrate_win"
  datadiscrate_rc$discrate_se <- databoot$discrate_se_win
  names(datadiscrate_rc)[names(datadiscrate_rc)=="discrate_se"] <- "discrate_se_win"

  #omitting missing standard errors + dropping variable Negative.framing (no observations within this specification)
  bmaData_rc <- na.omit(datadiscrate_rc)[ , c(1:14,16:23)]

  #renaming data for visualization
  names(bmaData_rc) <- as.list(var.labels[match(names(bmaData_rc), names(var.labels))])

#main BMA simulations
  discrate_rc = bms(bmaData_rc, burn=bmaBurns, iter=bmaIter, g="UIP", mprior="uniform", nmodel=bmaNmodel, mcmc="bd", user.int=FALSE)

#saving postestimation
  pdf("_discrate_post_rc.pdf")
  plot(discrate_rc)
  dev.off()

#summary stats
  summary(discrate_rc)
  coef(discrate_rc, order.by.pip = F, exact=T, include.constant=T)

#saving cumulative bma plot
  pdf("_discrate_bma_rc.pdf")
  image(discrate_rc, cex.axis=0.8, order.by.pip = T, yprop2pip=F)
  dev.off()

#top 5 models
  top5rc <- topmodels.bma(discrate_rc)[, 1:5]
  printLatex(top5rc, "top5rc", "Five top models of robustness check to BMA analysis")
  toprc <- discrate_rc$topmod[1] #included variables in the best model
  print(toprc)

# Best model
  rc_best <- as.zlm(discrate_rc, model = 1)
  summary(rc_best)
####################################
####################################
closeAllConnections()
